==> gitlab_17.3.5.orig.tar.bz2: gitlab-foss-v17.3.5/spec/frontend/admin/signup_restrictions/mock_data.js <==
export const rawMockData = {
  host: 'path/to/host',
  settingsPath: 'path/to/settings',
  signupEnabled: 'true',
  requireAdminApprovalAfterUserSignup: 'true',
  emailConfirmationSetting: 'hard',
  minimumPasswordLength: '8',
  minimumPasswordLengthMin: '3',
  minimumPasswordLengthMax: '10',
  minimumPasswordLengthHelpLink: 'help/link',
  domainAllowlistRaw: 'domain1.com, domain2.com',
  newUserSignupsCap: '8',
  domainDenylistEnabled: 'true',
  denylistTypeRawSelected: 'true',
  domainDenylistRaw: 'domain2.com, domain3.com',
  emailRestrictionsEnabled: 'true',
  supportedSyntaxLinkUrl: '/supported/syntax/link',
  emailRestrictions: 'user1@domain.com, user2@domain.com',
  afterSignUpText: 'Congratulations on your successful sign-up!',
  pendingUserCount: '0',
  passwordNumberRequired: 'true',
  passwordLowercaseRequired: 'true',
  passwordUppercaseRequired: 'true',
  passwordSymbolRequired: 'true',
  promotionManagementAvailable: 'true',
  enableMemberPromotionManagement: 'true',
};

export const mockData = {
  host: 'path/to/host',
  settingsPath: 'path/to/settings',
  signupEnabled: true,
  requireAdminApprovalAfterUserSignup: true,
  emailConfirmationSetting: 'hard',
  minimumPasswordLength: '8',
  minimumPasswordLengthMin: '3',
  minimumPasswordLengthMax: '10',
  minimumPasswordLengthHelpLink: 'help/link',
  domainAllowlistRaw: 'domain1.com, domain2.com',
  newUserSignupsCap: '8',
  domainDenylistEnabled: true,
  denylistTypeRawSelected: true,
  domainDenylistRaw: 'domain2.com, domain3.com',
  emailRestrictionsEnabled: true,
  supportedSyntaxLinkUrl: '/supported/syntax/link',
  emailRestrictions: 'user1@domain.com, user2@domain.com',
  afterSignUpText: 'Congratulations on your successful sign-up!',
  pendingUserCount: '0',
  passwordNumberRequired: true,
  passwordLowercaseRequired: true,
  passwordUppercaseRequired: true,
  passwordSymbolRequired: true,
  promotionManagementAvailable: true,
  enableMemberPromotionManagement: true,
};

==> gitlab_17.6.5.orig.tar.bz2: gitlab-foss-v17.6.5/spec/frontend/admin/signup_restrictions/mock_data.js <==
export const rawMockData = {
  host: 'path/to/host',
  settingsPath: 'path/to/settings',
  signupEnabled: 'true',
  requireAdminApprovalAfterUserSignup: 'true',
  emailConfirmationSetting: 'hard',
  minimumPasswordLength: '8',
  minimumPasswordLengthMin: '3',
  minimumPasswordLengthMax: '10',
  minimumPasswordLengthHelpLink: 'help/link',
  domainAllowlistRaw: 'domain1.com, domain2.com',
  newUserSignupsCap: '8',
  domainDenylistEnabled: 'true',
  denylistTypeRawSelected: 'true',
  domainDenylistRaw: 'domain2.com, domain3.com',
  emailRestrictionsEnabled: 'true',
  supportedSyntaxLinkUrl: '/supported/syntax/link',
  emailRestrictions: 'user1@domain.com, user2@domain.com',
  afterSignUpText: 'Congratulations on your successful sign-up!',
  pendingUserCount: '0',
  passwordNumberRequired: 'true',
  passwordLowercaseRequired: 'true',
  passwordUppercaseRequired: 'true',
  passwordSymbolRequired: 'true',
  promotionManagementAvailable: 'true',
  enableMemberPromotionManagement: 'true',
  canDisableMemberPromotionManagement: false,
  rolePromotionRequestsPath: '/admin/role_promotion',
  licensedUserCount: '',
};

export const mockData = {
  host: 'path/to/host',
  settingsPath: 'path/to/settings',
  signupEnabled: true,
  requireAdminApprovalAfterUserSignup: true,
  emailConfirmationSetting: 'hard',
  minimumPasswordLength: '8',
  minimumPasswordLengthMin: '3',
  minimumPasswordLengthMax: '10',
  minimumPasswordLengthHelpLink: 'help/link',
  domainAllowlistRaw: 'domain1.com, domain2.com',
  newUserSignupsCap: '8',
  domainDenylistEnabled: true,
  denylistTypeRawSelected: true,
  domainDenylistRaw: 'domain2.com, domain3.com',
  emailRestrictionsEnabled: true,
  supportedSyntaxLinkUrl: '/supported/syntax/link',
  emailRestrictions: 'user1@domain.com, user2@domain.com',
  afterSignUpText: 'Congratulations on your successful sign-up!',
  pendingUserCount: '0',
  passwordNumberRequired: true,
  passwordLowercaseRequired: true,
  passwordUppercaseRequired: true,
  passwordSymbolRequired: true,
  promotionManagementAvailable: true,
  enableMemberPromotionManagement: true,
  canDisableMemberPromotionManagement: false,
  rolePromotionRequestsPath: '/admin/role_promotion',
  licensedUserCount: '',
};
